==> zio-aws-amplifybackend_3-5.17.124.3-sources.jar: zio/aws/amplifybackend/model/RemoveBackendConfigRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class RemoveBackendConfigRequest(appId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest = {
    import RemoveBackendConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
      .builder()
      .appId(__string.unwrap(appId): java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly =
    zio.aws.amplifybackend.model.RemoveBackendConfigRequest
      .wrap(buildAwsValue())
}
object RemoveBackendConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.RemoveBackendConfigRequest =
      zio.aws.amplifybackend.model.RemoveBackendConfigRequest(appId)
    def appId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ) extends zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly {
    override val appId: __string =
      zio.aws.amplifybackend.model.primitives.__string(impl.appId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ): zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.17.295.1-sources.jar: zio/aws/amplifybackend/model/RemoveBackendConfigRequest.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters.*
final case class RemoveBackendConfigRequest(appId: __string) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest = {
    import RemoveBackendConfigRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
      .builder()
      .appId(appId: java.lang.String)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly =
    zio.aws.amplifybackend.model.RemoveBackendConfigRequest
      .wrap(buildAwsValue())
}
object RemoveBackendConfigRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.RemoveBackendConfigRequest =
      zio.aws.amplifybackend.model.RemoveBackendConfigRequest(appId)
    def appId: __string
    def getAppId: ZIO[Any, Nothing, __string] = ZIO.succeed(appId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ) extends zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly {
    override val appId: __string = impl.appId(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigRequest
  ): zio.aws.amplifybackend.model.RemoveBackendConfigRequest.ReadOnly =
    new Wrapper(impl)
}
